@@ -18,14 +18,15 @@ c         MovedTrack has complete information at path end.
 c         If a chargde ptcl, compute energy loss by dE/dx  and  reset energy
 c         in MovedTrack. If it is too large, path is truncated. Also compute
 c         deflection.
-c
-       if(TrackBefMove.p.charge .ne. 0) then
-c          if(.not. (mod(HowGeomag, 10) .eq. 1 .and.     this existed from uv4.92 to 5.13
+       if(IntInfArray(ProcessNo).length .gt. 0.0 ) then
+          if(TrackBefMove.p.charge .ne. 0) then
+c            if(.not. (mod(HowGeomag, 10) .eq. 1 .and.     this existed from uv4.92 to 5.13
 c     *                Zfirst .eq. 0.)) then
              call cputEnergyLoss
-c          endif
-          if(MoveStat .ne. Dead) then
-             call cputDeflection
+c               endif
+             if(MoveStat .ne. Dead) then
+                call cputDeflection
+             endif
           endif
        endif
        end
@@ -274,7 +275,11 @@ c                                               same as cbDefByRK
 c
        if(UseRungeKutta .eq. 8 ) then
           call cbDefUser(TrackBefMove,  leng,  dispmr, dispmd)
-          MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#if defined SUBSTREC             
+             MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#else 
+             call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
           goto 100
        endif
        high = TrackBefMove.pos.height .gt. cheight
@@ -300,7 +305,7 @@ c
        elseif(usecmiddle) then
 c            get curved middle point
           call cmagneticDef(TrackBefMove, Mag, leng/2.0d0,
-     *     dispmr, dispmd)
+     *     dispmr, dispmd)  
           do i = 1, 3
              middle.r(i) = TrackBefMove.pos.xyz.r(i) + dispmr.r(i)
           enddo
@@ -319,7 +324,11 @@ c            get curved middle point
 c           if  dB/B~ dB^2/B^2/2 > 0.4 %, use RungeKutta.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
              call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#else 
+             call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
              goto 100
           else
              Mag = tempmag
@@ -332,7 +341,11 @@ c                  next 4.5d-3 is very sensitive to cpu time
 c                 if it was 4.0d-3, cpu time becomes twice.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.5d-3) then
              call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#else 
+             call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
              goto 100
           else
              Mag = tempmag
@@ -343,7 +356,11 @@ c                 if it was 4.0d-3, cpu time becomes twice.
 c           if  dB/B~ dB^2/B^2/2 > 0.1 %, use RungeKutta.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
              call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#else 
+             call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
              goto 100
           else
              Mag = tempmag
