@@ -556,6 +556,7 @@ c      If so, current particle is decomposed into nucelons and put into stack
 c      and icon =1  is made. else icon = 0
       subroutine  cforceSSP(atrack, icon)
 #include "Ztrack.h"
+#include "Zevhnv.h"
 #include "Zevhnp.h"
 #include "Zcode.h"
 #include "Zmass.h"
@@ -586,8 +587,14 @@ c      and icon =1  is made. else icon = 0
          pj.p.charge = 1
 
          p = sqrt(pj.p.fm.p(4)**2 - masp**2)      
-         po = atrack.p.fm.p(1)**2 + atrack.p.fm.p(2)**2 +
-     *           atrack.p.fm.p(3)**2 
+c          next one leads to seg. violation on opteron and ifc64
+cc         po = atrack.p.fm.p(1)**2 + atrack.p.fm.p(2)**2 +
+cc     *           atrack.p.fm.p(3)**2 
+cc       (  still by version 9. )
+
+         po = atrack.p.fm.p(1)**2 + atrack.p.fm.p(2)**2
+         po = po +  atrack.p.fm.p(3)**2 
+
          po = sqrt(po)
          pr = p/po
          do j = 1, 3
